==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/CreateRequest.java <==
package com.example.model;

@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "")
public class CreateRequest implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	@io.swagger.annotations.ApiModel(value = "")
	public static class Notifications implements java.io.Serializable {
	
		private static final long serialVersionUID = 1L;
		@io.swagger.annotations.ApiModel(value = "")
		public static class Complete implements java.io.Serializable {
		
			private static final long serialVersionUID = 1L;
			private java.lang.String authHeaderName = null;
			private java.lang.String authHeaderValue = null;
			private java.lang.String type = null;
			private java.lang.String url = null;
			
			/**
			 * Optional Name of an authorization header for us to use when contacting your webhook URL.
			 */
			public Complete authHeaderName(java.lang.String authHeaderName) {
				setAuthHeaderName(authHeaderName);
				return this;
			}
			
			@io.swagger.annotations.ApiModelProperty(required = true, value = "Optional Name of an authorization header for us to use when contacting your webhook URL.")
			@com.fasterxml.jackson.annotation.JsonProperty("auth_header_name")
			@javax.validation.constraints.NotNull
			public java.lang.String getAuthHeaderName() {
				return this.authHeaderName;
			}
			public void setAuthHeaderName(java.lang.String authHeaderName) {
				this.authHeaderName = authHeaderName;
			}
			
			/**
			 * Optional Value of an authorization header for us to use when contacting your webhook URL.
			 */
			public Complete authHeaderValue(java.lang.String authHeaderValue) {
				setAuthHeaderValue(authHeaderValue);
				return this;
			}
			
			@io.swagger.annotations.ApiModelProperty(value = "Optional Value of an authorization header for us to use when contacting your webhook URL.")
			@com.fasterxml.jackson.annotation.JsonProperty("auth_header_value")
			public java.lang.String getAuthHeaderValue() {
				return this.authHeaderValue;
			}
			public void setAuthHeaderValue(java.lang.String authHeaderValue) {
				this.authHeaderValue = authHeaderValue;
			}
			
			/**
			 */
			public Complete type(java.lang.String type) {
				setType(type);
				return this;
			}
			
			@io.swagger.annotations.ApiModelProperty(value = "")
			@com.fasterxml.jackson.annotation.JsonProperty("type")
			public java.lang.String getType() {
				return this.type;
			}
			public void setType(java.lang.String type) {
				this.type = type;
			}
			
			/**
			 * Your webhook URL for where we should send the notification that the transaction has been completed.
			 */
			public Complete url(java.lang.String url) {
				setUrl(url);
				return this;
			}
			
			@io.swagger.annotations.ApiModelProperty(value = "Your webhook URL for where we should send the notification that the transaction has been completed.")
			@com.fasterxml.jackson.annotation.JsonProperty("url")
			public java.lang.String getUrl() {
				return this.url;
			}
			public void setUrl(java.lang.String url) {
				this.url = url;
			}
			
			@Override
			public boolean equals(java.lang.Object o) {
				if (this == o) {
					return true;
				}
				if (o == null || getClass() != o.getClass()) {
					return false;
				}
				Complete complete = (Complete) o;
				return java.util.Objects.equals(this.authHeaderName, complete.authHeaderName)
						&& java.util.Objects.equals(this.authHeaderValue, complete.authHeaderValue)
						&& java.util.Objects.equals(this.type, complete.type)
						&& java.util.Objects.equals(this.url, complete.url);
			}
			
			@Override
			public int hashCode() {
				return java.util.Objects.hash(this.authHeaderName, this.authHeaderValue, this.type, this.url);
			}
			
			@Override
			public String toString() {
				StringBuilder sb = new StringBuilder();
				sb.append("class Complete {\n");
				
				sb.append("    authHeaderName: ").append(toIndentedString(this.authHeaderName)).append("\n");
				sb.append("    authHeaderValue: ").append(toIndentedString(this.authHeaderValue)).append("\n");
				sb.append("    type: ").append(toIndentedString(this.type)).append("\n");
				sb.append("    url: ").append(toIndentedString(this.url)).append("\n");
				sb.append("}");
				return sb.toString();
			}
			
			/**
			 * Convert the given object to string with each line indented by 4 spaces
			 * (except the first line).
			 */
			private String toIndentedString(java.lang.Object o) {
				if (o == null) {
					return "null";
				}
				return o.toString().replace("\n", "\n    ");
			}
			
		}
		
		private java.util.List<com.example.model.CreateRequest.Notifications.Complete> complete = new java.util.ArrayList<com.example.model.CreateRequest.Notifications.Complete>();
		
		/**
		 */
		public Notifications complete(java.util.List<com.example.model.CreateRequest.Notifications.Complete> complete) {
			setComplete(complete);
			return this;
		}
		
		@io.swagger.annotations.ApiModelProperty(required = true, value = "")
		@com.fasterxml.jackson.annotation.JsonProperty("complete")
		@javax.validation.Valid
		@javax.validation.constraints.NotNull
		public java.util.List<com.example.model.CreateRequest.Notifications.Complete> getComplete() {
			return this.complete;
		}
		public void setComplete(java.util.List<com.example.model.CreateRequest.Notifications.Complete> complete) {
			this.complete = complete;
		}
		public Notifications addComplete(com.example.model.CreateRequest.Notifications.Complete complete) {
			if (this.complete == null) {
				this.complete = new java.util.ArrayList<com.example.model.CreateRequest.Notifications.Complete>();
			}
			this.complete.add(complete);
			return this;
		}
		
		@Override
		public boolean equals(java.lang.Object o) {
			if (this == o) {
				return true;
			}
			if (o == null || getClass() != o.getClass()) {
				return false;
			}
			Notifications notifications = (Notifications) o;
			return java.util.Objects.equals(this.complete, notifications.complete);
		}
		
		@Override
		public int hashCode() {
			return java.util.Objects.hash(this.complete);
		}
		
		@Override
		public String toString() {
			StringBuilder sb = new StringBuilder();
			sb.append("class Notifications {\n");
			
			sb.append("    complete: ").append(toIndentedString(this.complete)).append("\n");
			sb.append("}");
			return sb.toString();
		}
		
		/**
		 * Convert the given object to string with each line indented by 4 spaces
		 * (except the first line).
		 */
		private String toIndentedString(java.lang.Object o) {
			if (o == null) {
				return "null";
			}
			return o.toString().replace("\n", "\n    ");
		}
		
	}
	
	private java.lang.String flowType = null;
	private java.lang.String name = null;
	private com.example.model.CreateRequest.Notifications notifications = null;
	private java.lang.String phoneNumber = null;
	private java.lang.String phoneRegionCode = null;
	private java.lang.String redirectUrlExit = null;
	private java.lang.String redirectUrlSuccess = null;
	private java.lang.String reference = null;
	
	/**
	 */
	public CreateRequest flowType(java.lang.String flowType) {
		setFlowType(flowType);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("flow_type")
	@javax.validation.constraints.NotNull
	public java.lang.String getFlowType() {
		return this.flowType;
	}
	public void setFlowType(java.lang.String flowType) {
		this.flowType = flowType;
	}
	
	/**
	 * You can specify a &quot;name&quot; reference that may be seen in the SMS and is stored in the transaction record. (eg. Daniel).
	 */
	public CreateRequest name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "You can specify a \"name\" reference that may be seen in the SMS and is stored in the transaction record. (eg. Daniel).")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public CreateRequest notifications(com.example.model.CreateRequest.Notifications notifications) {
		setNotifications(notifications);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("notifications")
	@javax.validation.Valid
	public com.example.model.CreateRequest.Notifications getNotifications() {
		return this.notifications;
	}
	public void setNotifications(com.example.model.CreateRequest.Notifications notifications) {
		this.notifications = notifications;
	}
	
	/**
	 */
	public CreateRequest phoneNumber(java.lang.String phoneNumber) {
		setPhoneNumber(phoneNumber);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("phone_number")
	public java.lang.String getPhoneNumber() {
		return this.phoneNumber;
	}
	public void setPhoneNumber(java.lang.String phoneNumber) {
		this.phoneNumber = phoneNumber;
	}
	
	/**
	 * The region code for the mobile number (eg. +61)
	 */
	public CreateRequest phoneRegionCode(java.lang.String phoneRegionCode) {
		setPhoneRegionCode(phoneRegionCode);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "The region code for the mobile number (eg. +61)")
	@com.fasterxml.jackson.annotation.JsonProperty("phone_region_code")
	public java.lang.String getPhoneRegionCode() {
		return this.phoneRegionCode;
	}
	public void setPhoneRegionCode(java.lang.String phoneRegionCode) {
		this.phoneRegionCode = phoneRegionCode;
	}
	
	/**
	 * A URL for the customer to be redirected to if exiting within the journey without completing.
	 */
	public CreateRequest redirectUrlExit(java.lang.String redirectUrlExit) {
		setRedirectUrlExit(redirectUrlExit);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "A URL for the customer to be redirected to if exiting within the journey without completing.")
	@com.fasterxml.jackson.annotation.JsonProperty("redirect_url_exit")
	public java.lang.String getRedirectUrlExit() {
		return this.redirectUrlExit;
	}
	public void setRedirectUrlExit(java.lang.String redirectUrlExit) {
		this.redirectUrlExit = redirectUrlExit;
	}
	
	/**
	 * A URL for the customer to be redirected to once successfully completing the journey.
	 */
	public CreateRequest redirectUrlSuccess(java.lang.String redirectUrlSuccess) {
		setRedirectUrlSuccess(redirectUrlSuccess);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "A URL for the customer to be redirected to once successfully completing the journey.")
	@com.fasterxml.jackson.annotation.JsonProperty("redirect_url_success")
	public java.lang.String getRedirectUrlSuccess() {
		return this.redirectUrlSuccess;
	}
	public void setRedirectUrlSuccess(java.lang.String redirectUrlSuccess) {
		this.redirectUrlSuccess = redirectUrlSuccess;
	}
	
	/**
	 */
	public CreateRequest reference(java.lang.String reference) {
		setReference(reference);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("reference")
	public java.lang.String getReference() {
		return this.reference;
	}
	public void setReference(java.lang.String reference) {
		this.reference = reference;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		CreateRequest createRequest = (CreateRequest) o;
		return java.util.Objects.equals(this.flowType, createRequest.flowType)
				&& java.util.Objects.equals(this.name, createRequest.name)
				&& java.util.Objects.equals(this.notifications, createRequest.notifications)
				&& java.util.Objects.equals(this.phoneNumber, createRequest.phoneNumber)
				&& java.util.Objects.equals(this.phoneRegionCode, createRequest.phoneRegionCode)
				&& java.util.Objects.equals(this.redirectUrlExit, createRequest.redirectUrlExit)
				&& java.util.Objects.equals(this.redirectUrlSuccess, createRequest.redirectUrlSuccess)
				&& java.util.Objects.equals(this.reference, createRequest.reference);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.flowType, this.name, this.notifications, this.phoneNumber, this.phoneRegionCode, this.redirectUrlExit, this.redirectUrlSuccess, this.reference);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class CreateRequest {\n");
		
		sb.append("    flowType: ").append(toIndentedString(this.flowType)).append("\n");
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    notifications: ").append(toIndentedString(this.notifications)).append("\n");
		sb.append("    phoneNumber: ").append(toIndentedString(this.phoneNumber)).append("\n");
		sb.append("    phoneRegionCode: ").append(toIndentedString(this.phoneRegionCode)).append("\n");
		sb.append("    redirectUrlExit: ").append(toIndentedString(this.redirectUrlExit)).append("\n");
		sb.append("    redirectUrlSuccess: ").append(toIndentedString(this.redirectUrlSuccess)).append("\n");
		sb.append("    reference: ").append(toIndentedString(this.reference)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/CreateRequest.java <==
package com.example.model;

@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "")
public class CreateRequest implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	@io.swagger.v3.oas.annotations.media.Schema(name = "")
	public static class Notifications implements java.io.Serializable {
	
		private static final long serialVersionUID = 1L;
		@io.swagger.v3.oas.annotations.media.Schema(name = "")
		public static class Complete implements java.io.Serializable {
		
			private static final long serialVersionUID = 1L;
			private java.lang.String authHeaderName = null;
			private java.lang.String authHeaderValue = null;
			private java.lang.String type = null;
			private java.lang.String url = null;
			
			/**
			 * Optional Name of an authorization header for us to use when contacting your webhook URL.
			 */
			public Complete authHeaderName(java.lang.String authHeaderName) {
				setAuthHeaderName(authHeaderName);
				return this;
			}
			
			@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "auth_header_name", description = "Optional Name of an authorization header for us to use when contacting your webhook URL.")
			@com.fasterxml.jackson.annotation.JsonProperty("auth_header_name")
			@javax.validation.constraints.NotNull
			public java.lang.String getAuthHeaderName() {
				return this.authHeaderName;
			}
			public void setAuthHeaderName(java.lang.String authHeaderName) {
				this.authHeaderName = authHeaderName;
			}
			
			/**
			 * Optional Value of an authorization header for us to use when contacting your webhook URL.
			 */
			public Complete authHeaderValue(java.lang.String authHeaderValue) {
				setAuthHeaderValue(authHeaderValue);
				return this;
			}
			
			@io.swagger.v3.oas.annotations.media.Schema(name = "auth_header_value", description = "Optional Value of an authorization header for us to use when contacting your webhook URL.")
			@com.fasterxml.jackson.annotation.JsonProperty("auth_header_value")
			public java.lang.String getAuthHeaderValue() {
				return this.authHeaderValue;
			}
			public void setAuthHeaderValue(java.lang.String authHeaderValue) {
				this.authHeaderValue = authHeaderValue;
			}
			
			/**
			 */
			public Complete type(java.lang.String type) {
				setType(type);
				return this;
			}
			
			@io.swagger.v3.oas.annotations.media.Schema(name = "type")
			@com.fasterxml.jackson.annotation.JsonProperty("type")
			public java.lang.String getType() {
				return this.type;
			}
			public void setType(java.lang.String type) {
				this.type = type;
			}
			
			/**
			 * Your webhook URL for where we should send the notification that the transaction has been completed.
			 */
			public Complete url(java.lang.String url) {
				setUrl(url);
				return this;
			}
			
			@io.swagger.v3.oas.annotations.media.Schema(name = "url", description = "Your webhook URL for where we should send the notification that the transaction has been completed.")
			@com.fasterxml.jackson.annotation.JsonProperty("url")
			public java.lang.String getUrl() {
				return this.url;
			}
			public void setUrl(java.lang.String url) {
				this.url = url;
			}
			
			@Override
			public boolean equals(java.lang.Object o) {
				if (this == o) {
					return true;
				}
				if (o == null || getClass() != o.getClass()) {
					return false;
				}
				Complete complete = (Complete) o;
				return java.util.Objects.equals(this.authHeaderName, complete.authHeaderName)
						&& java.util.Objects.equals(this.authHeaderValue, complete.authHeaderValue)
						&& java.util.Objects.equals(this.type, complete.type)
						&& java.util.Objects.equals(this.url, complete.url);
			}
			
			@Override
			public int hashCode() {
				return java.util.Objects.hash(this.authHeaderName, this.authHeaderValue, this.type, this.url);
			}
			
			@Override
			public String toString() {
				StringBuilder sb = new StringBuilder();
				sb.append("class Complete {\n");
				
				sb.append("    authHeaderName: ").append(toIndentedString(this.authHeaderName)).append("\n");
				sb.append("    authHeaderValue: ").append(toIndentedString(this.authHeaderValue)).append("\n");
				sb.append("    type: ").append(toIndentedString(this.type)).append("\n");
				sb.append("    url: ").append(toIndentedString(this.url)).append("\n");
				sb.append("}");
				return sb.toString();
			}
			
			/**
			 * Convert the given object to string with each line indented by 4 spaces
			 * (except the first line).
			 */
			private String toIndentedString(java.lang.Object o) {
				if (o == null) {
					return "null";
				}
				return o.toString().replace("\n", "\n    ");
			}
			
		}
		
		private java.util.List<com.example.model.CreateRequest.Notifications.Complete> complete = new java.util.ArrayList<com.example.model.CreateRequest.Notifications.Complete>();
		
		/**
		 */
		public Notifications complete(java.util.List<com.example.model.CreateRequest.Notifications.Complete> complete) {
			setComplete(complete);
			return this;
		}
		
		@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "complete")
		@com.fasterxml.jackson.annotation.JsonProperty("complete")
		@javax.validation.Valid
		@javax.validation.constraints.NotNull
		public java.util.List<com.example.model.CreateRequest.Notifications.Complete> getComplete() {
			return this.complete;
		}
		public void setComplete(java.util.List<com.example.model.CreateRequest.Notifications.Complete> complete) {
			this.complete = complete;
		}
		public Notifications addComplete(com.example.model.CreateRequest.Notifications.Complete complete) {
			if (this.complete == null) {
				this.complete = new java.util.ArrayList<com.example.model.CreateRequest.Notifications.Complete>();
			}
			this.complete.add(complete);
			return this;
		}
		
		@Override
		public boolean equals(java.lang.Object o) {
			if (this == o) {
				return true;
			}
			if (o == null || getClass() != o.getClass()) {
				return false;
			}
			Notifications notifications = (Notifications) o;
			return java.util.Objects.equals(this.complete, notifications.complete);
		}
		
		@Override
		public int hashCode() {
			return java.util.Objects.hash(this.complete);
		}
		
		@Override
		public String toString() {
			StringBuilder sb = new StringBuilder();
			sb.append("class Notifications {\n");
			
			sb.append("    complete: ").append(toIndentedString(this.complete)).append("\n");
			sb.append("}");
			return sb.toString();
		}
		
		/**
		 * Convert the given object to string with each line indented by 4 spaces
		 * (except the first line).
		 */
		private String toIndentedString(java.lang.Object o) {
			if (o == null) {
				return "null";
			}
			return o.toString().replace("\n", "\n    ");
		}
		
	}
	
	private java.lang.String flowType = null;
	private java.lang.String name = null;
	private com.example.model.CreateRequest.Notifications notifications = null;
	private java.lang.String phoneNumber = null;
	private java.lang.String phoneRegionCode = null;
	private java.lang.String redirectUrlExit = null;
	private java.lang.String redirectUrlSuccess = null;
	private java.lang.String reference = null;
	
	/**
	 */
	public CreateRequest flowType(java.lang.String flowType) {
		setFlowType(flowType);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "flow_type")
	@com.fasterxml.jackson.annotation.JsonProperty("flow_type")
	@javax.validation.constraints.NotNull
	public java.lang.String getFlowType() {
		return this.flowType;
	}
	public void setFlowType(java.lang.String flowType) {
		this.flowType = flowType;
	}
	
	/**
	 * You can specify a &quot;name&quot; reference that may be seen in the SMS and is stored in the transaction record. (eg. Daniel).
	 */
	public CreateRequest name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "name", description = "You can specify a \"name\" reference that may be seen in the SMS and is stored in the transaction record. (eg. Daniel).")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public CreateRequest notifications(com.example.model.CreateRequest.Notifications notifications) {
		setNotifications(notifications);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "notifications")
	@com.fasterxml.jackson.annotation.JsonProperty("notifications")
	@javax.validation.Valid
	public com.example.model.CreateRequest.Notifications getNotifications() {
		return this.notifications;
	}
	public void setNotifications(com.example.model.CreateRequest.Notifications notifications) {
		this.notifications = notifications;
	}
	
	/**
	 */
	public CreateRequest phoneNumber(java.lang.String phoneNumber) {
		setPhoneNumber(phoneNumber);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "phone_number")
	@com.fasterxml.jackson.annotation.JsonProperty("phone_number")
	public java.lang.String getPhoneNumber() {
		return this.phoneNumber;
	}
	public void setPhoneNumber(java.lang.String phoneNumber) {
		this.phoneNumber = phoneNumber;
	}
	
	/**
	 * The region code for the mobile number (eg. +61)
	 */
	public CreateRequest phoneRegionCode(java.lang.String phoneRegionCode) {
		setPhoneRegionCode(phoneRegionCode);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "phone_region_code", description = "The region code for the mobile number (eg. +61)")
	@com.fasterxml.jackson.annotation.JsonProperty("phone_region_code")
	public java.lang.String getPhoneRegionCode() {
		return this.phoneRegionCode;
	}
	public void setPhoneRegionCode(java.lang.String phoneRegionCode) {
		this.phoneRegionCode = phoneRegionCode;
	}
	
	/**
	 * A URL for the customer to be redirected to if exiting within the journey without completing.
	 */
	public CreateRequest redirectUrlExit(java.lang.String redirectUrlExit) {
		setRedirectUrlExit(redirectUrlExit);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "redirect_url_exit", description = "A URL for the customer to be redirected to if exiting within the journey without completing.")
	@com.fasterxml.jackson.annotation.JsonProperty("redirect_url_exit")
	public java.lang.String getRedirectUrlExit() {
		return this.redirectUrlExit;
	}
	public void setRedirectUrlExit(java.lang.String redirectUrlExit) {
		this.redirectUrlExit = redirectUrlExit;
	}
	
	/**
	 * A URL for the customer to be redirected to once successfully completing the journey.
	 */
	public CreateRequest redirectUrlSuccess(java.lang.String redirectUrlSuccess) {
		setRedirectUrlSuccess(redirectUrlSuccess);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "redirect_url_success", description = "A URL for the customer to be redirected to once successfully completing the journey.")
	@com.fasterxml.jackson.annotation.JsonProperty("redirect_url_success")
	public java.lang.String getRedirectUrlSuccess() {
		return this.redirectUrlSuccess;
	}
	public void setRedirectUrlSuccess(java.lang.String redirectUrlSuccess) {
		this.redirectUrlSuccess = redirectUrlSuccess;
	}
	
	/**
	 */
	public CreateRequest reference(java.lang.String reference) {
		setReference(reference);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "reference")
	@com.fasterxml.jackson.annotation.JsonProperty("reference")
	public java.lang.String getReference() {
		return this.reference;
	}
	public void setReference(java.lang.String reference) {
		this.reference = reference;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		CreateRequest createRequest = (CreateRequest) o;
		return java.util.Objects.equals(this.flowType, createRequest.flowType)
				&& java.util.Objects.equals(this.name, createRequest.name)
				&& java.util.Objects.equals(this.notifications, createRequest.notifications)
				&& java.util.Objects.equals(this.phoneNumber, createRequest.phoneNumber)
				&& java.util.Objects.equals(this.phoneRegionCode, createRequest.phoneRegionCode)
				&& java.util.Objects.equals(this.redirectUrlExit, createRequest.redirectUrlExit)
				&& java.util.Objects.equals(this.redirectUrlSuccess, createRequest.redirectUrlSuccess)
				&& java.util.Objects.equals(this.reference, createRequest.reference);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.flowType, this.name, this.notifications, this.phoneNumber, this.phoneRegionCode, this.redirectUrlExit, this.redirectUrlSuccess, this.reference);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class CreateRequest {\n");
		
		sb.append("    flowType: ").append(toIndentedString(this.flowType)).append("\n");
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    notifications: ").append(toIndentedString(this.notifications)).append("\n");
		sb.append("    phoneNumber: ").append(toIndentedString(this.phoneNumber)).append("\n");
		sb.append("    phoneRegionCode: ").append(toIndentedString(this.phoneRegionCode)).append("\n");
		sb.append("    redirectUrlExit: ").append(toIndentedString(this.redirectUrlExit)).append("\n");
		sb.append("    redirectUrlSuccess: ").append(toIndentedString(this.redirectUrlSuccess)).append("\n");
		sb.append("    reference: ").append(toIndentedString(this.reference)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
